contentstorage/cautils/inc/cainnerentry.h
changeset 98 d2f833ab7940
parent 92 782e3408c2ab
child 127 7b66bc3c6dc9
--- a/contentstorage/cautils/inc/cainnerentry.h	Tue Jun 01 11:30:17 2010 +0300
+++ b/contentstorage/cautils/inc/cainnerentry.h	Fri Jun 11 16:13:51 2010 +0300
@@ -30,6 +30,12 @@
     {
 public:
 
+
+    enum TLocalizedType
+        {
+        ENameLocalized = 0,
+        EDescriptionLocalized
+        };
     /**
      * Destructor.
      */
@@ -116,16 +122,17 @@
     IMPORT_C void SetId( TUint aId );
 
     /**
      * Sets the entry text.
      * @param aText Entry text.
      */
-    IMPORT_C void SetTextL( const TDesC& aText );
-
+    IMPORT_C void SetTextL( 
+            const TDesC& aText, TBool localized = false );    
     /**
      * Sets the entry description.
      * @param aText Entry description.
      */
-    IMPORT_C void SetDescriptionL( const TDesC& aText );
+    IMPORT_C void SetDescriptionL( 
+            const TDesC& aText, TBool localized = false );
 
     /**
      * Sets the entry typename.
@@ -206,6 +213,12 @@
      * @param aStream a read stream
      */
     IMPORT_C void InternalizeL( RReadStream& aStream );
+    
+    /**
+     * Gets if Description is localized.
+     * @return ETrue if entry desscription is localized.
+     */
+    IMPORT_C TBool isLocalized(TLocalizedType aLocalized) const;
 
 private:
 
@@ -270,6 +283,11 @@
      * Uid
      */
     TInt32 iUid;
+    
+    TBool iTextLocalized;
+    
+    TBool iDescriptionLocalized;
+    
 
     };
@@ -116,16 +122,17 @@
 
     /**
-     * Sets the entry text.
+     * Sets localized entry text.
      * @param aText Entry text.
      */
@@ -116,16 +122,17 @@
     /**
-     * Sets the entry description.
+     * Sets localized entry description.
      * @param aText Entry description.
      */